window.Gleam.initSearch([{"doc":"cake_sqlight","title":"cake_sqlight","content":"# Adapter between `cake` and `sqlight`\n\n[![Package &lt;a href=&quot;https://github.com/inoas/gleam-cake-sqlight/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/inoas/gleam-cake-sqlight&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt; Version](https://img.shields.io/hexpm/v/cake_sqlight)](https://hex.pm/packages/cake_sqlight)\n[![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)](https://www.erlang.org/)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/cake_sqlight/)\n[![Discord](https://img.shields.io/discord/768594524158427167?label=discord%20chat&amp;amp;color=5865F2)](https://discord.gg/Fm8Pwmy)\n\n&lt;!--\n[![CI Test](https://github.com/inoas/gleam-cake-sqlight/actions/workflows/test.yml/badge.svg?branch=main&amp;amp;event=push)](https://github.com/inoas/gleam-cake-sqlight/actions/workflows/test.yml)\n--&gt;\n\n🎂[Cake](http://hex.pm/packages/cake) 🪶SQLite adapter which passes `PreparedStatement`s to the [sqlight](http://hex.pm/packages/sqlight) library for execution written in [Gleam](https://gleam.run/).\n\n## Installation\n\n```sh\ngleam add cake_sqlight@1\n```\n\n## Example\n\nNotice: Official cake adapters re-use the cake namespace, thus you can import them like\nsuch: `import cake/adapter/sqlite`.\n\n```gleam\nimport cake/adapter/sqlite\nimport cake/delete as d\nimport cake/insert as i\nimport cake/select as s\nimport cake/where as w\nimport gleam/dynamic\n\nconst sqlite_database_filename = &quot;birds.sqlite3&quot;\n\npub fn main() {\n  // sqlite.with_memory_connection, fn(db_connection) { // If you only want to use an in-memory database\n  sqlite.with_connection(sqlite_database_filename, fn(db_connection) {\n    db_connection |&gt; create_table_if_not_exists_birds\n    db_connection |&gt; insert_into_table_birds\n    db_connection |&gt; select_from_table_birds\n    db_connection |&gt; delete_from_table_birds\n  })\n}\n\nfn create_table_if_not_exists_birds(db_connection) {\n  &quot;CREATE TABLE IF NOT EXISTS birds (\n    species TEXT,\n    average_weight FLOAT(8),\n    is_extinct BOOLEAN\n  );&quot;\n  |&gt; sqlite.execute_raw_sql(db_connection)\n  |&gt; io.debug\n}\n\nfn insert_into_table_birds(db_connection) {\n  [\n    [i.string(&quot;Dodo&quot;), i.float(14.05), i.bool(True)] |&gt; i.row,\n    [i.string(&quot;Great auk&quot;), i.float(5.0), i.bool(True)] |&gt; i.row,\n  ]\n  |&gt; i.from_values(\n      table_name: &quot;birds&quot;,\n      columns: [\n        &quot;species&quot;, &quot;average_weight&quot;, &quot;is_extinct&quot;,\n      ]\n  )\n  |&gt; i.to_query\n  |&gt; sqlite.run_write_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n\nfn select_from_table_birds(db_connection) {\n  s.new()\n  |&gt; s.from_table(&quot;table&quot;)\n  |&gt; s.selects([s.col(&quot;species&quot;)])\n  |&gt; s.to_query\n  |&gt; sqlite.run_read_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n\nfn delete_from_table_birds(db_connection) {\n  d.new()\n  |&gt; d.table(&quot;birds&quot;)\n  |&gt; d.where(w.col(&quot;species&quot;) |&gt; w.eq(w.string(&quot;Dodo&quot;)))\n  |&gt; d.to_query\n  |&gt; sqlite.run_write_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n```\n\n## Migrations\n\nYou may use the [storch library](http://hex.pm/packages/storch) to run SQLite\nmigrations.\n","url":"index.html"},{"doc":"cake_sqlight","title":"cake_sqlight","content":"# Changelog\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to\n[Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n&lt;!-- ## [Unreleased] --&gt;\n## [1.0.2] - 2024-11-03\n\n- Added omitted license file.\n\n## [1.0.1] - 2024-10-20\n\n- Relaxed dependency version constraints.\n\n## [1.0.0] - 2024-10-19\n\n- Initial release.\n","url":"changelog.html"},{"doc":"cake/adapter/sqlite","title":"execute_raw_sql","content":"pub fn execute_raw_sql(\n  sql_string sql_string: String,\n  db_connection db_connection: Connection,\n) -&gt; Result(Nil, Error)\n Execute a raw SQL query against an SQLite database.\n\nSynonyms:\ncake/adapter/sqlite.execute_raw_sql\ncake/adapter/sqlite execute_raw_sql","url":"cake/adapter/sqlite.html#execute_raw_sql"},{"doc":"cake/adapter/sqlite","title":"read_query_to_prepared_statement","content":"pub fn read_query_to_prepared_statement(\n  query query: ReadQuery,\n) -&gt; PreparedStatement\n Convert a Cake `ReadQuery` to a `PreparedStatement`.\n\nSynonyms:\ncake/adapter/sqlite.read_query_to_prepared_statement\ncake/adapter/sqlite read_query_to_prepared_statement","url":"cake/adapter/sqlite.html#read_query_to_prepared_statement"},{"doc":"cake/adapter/sqlite","title":"run_query","content":"pub fn run_query(\n  query query: CakeQuery(a),\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n Run a Cake `CakeQuery` against an SQLite database.\n\n This function is a wrapper around `run_read_query` and `run_write_query`.\n\nSynonyms:\ncake/adapter/sqlite.run_query\ncake/adapter/sqlite run_query","url":"cake/adapter/sqlite.html#run_query"},{"doc":"cake/adapter/sqlite","title":"run_read_query","content":"pub fn run_read_query(\n  query query: ReadQuery,\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n Run a Cake `ReadQuery` against an SQLite database.\n\nSynonyms:\ncake/adapter/sqlite.run_read_query\ncake/adapter/sqlite run_read_query","url":"cake/adapter/sqlite.html#run_read_query"},{"doc":"cake/adapter/sqlite","title":"run_write_query","content":"pub fn run_write_query(\n  query query: WriteQuery(a),\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), Error)\n Run a Cake `WriteQuery` against an SQLite database.\n\nSynonyms:\ncake/adapter/sqlite.run_write_query\ncake/adapter/sqlite run_write_query","url":"cake/adapter/sqlite.html#run_write_query"},{"doc":"cake/adapter/sqlite","title":"with_connection","content":"pub fn with_connection(\n  filename filename: String,\n  callback callback: fn(Connection) -&gt; a,\n) -&gt; a\n Connection to a SQLite database.\n\n This is a thin wrapper around the `sqlight` library&#39;s `Connection` type.\n\nSynonyms:\ncake/adapter/sqlite.with_connection\ncake/adapter/sqlite with_connection","url":"cake/adapter/sqlite.html#with_connection"},{"doc":"cake/adapter/sqlite","title":"with_memory_connection","content":"pub fn with_memory_connection(\n  callback callback: fn(Connection) -&gt; a,\n) -&gt; a\n Connection to an in-memory SQLite database.\n\n This is a thin wrapper around the `sqlight` library&#39;s `Connection` type.\n\nSynonyms:\ncake/adapter/sqlite.with_memory_connection\ncake/adapter/sqlite with_memory_connection","url":"cake/adapter/sqlite.html#with_memory_connection"},{"doc":"cake/adapter/sqlite","title":"write_query_to_prepared_statement","content":"pub fn write_query_to_prepared_statement(\n  query query: WriteQuery(a),\n) -&gt; PreparedStatement\n Convert a Cake `WriteQuery` to a `PreparedStatement`.\n\nSynonyms:\ncake/adapter/sqlite.write_query_to_prepared_statement\ncake/adapter/sqlite write_query_to_prepared_statement","url":"cake/adapter/sqlite.html#write_query_to_prepared_statement"},{"doc":"cake/adapter/sqlite","title":"cake/adapter/sqlite","content":" 🎂Cake 🪶SQLite adapter which passes `PreparedStatement`s\n to the `sqlight` library for execution.\n","url":"cake/adapter/sqlite.html"},{"doc":"cake_sqlight","title":"cake_sqlight","content":"","url":"cake_sqlight.html"}]);